pub struct DatabaseMetrics {
pub active_connections: u64,
pub idle_connections: u64,
pub total_connections: u64,
pub queries_executed: u64,
pub query_duration_ms: f64,
pub errors: u64,
}Fields
active_connections: u64idle_connections: u64total_connections: u64queries_executed: u64query_duration_ms: f64errors: u64Trait Implementations
Sourceimpl Clone for DatabaseMetrics
impl Clone for DatabaseMetrics
Sourcefn clone(&self) -> DatabaseMetrics
fn clone(&self) -> DatabaseMetrics
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatabaseMetrics
impl Debug for DatabaseMetrics
Sourceimpl Default for DatabaseMetrics
impl Default for DatabaseMetrics
Sourcefn default() -> DatabaseMetrics
fn default() -> DatabaseMetrics
Returns the “default value” for a type. Read more
Sourceimpl<'py> IntoPyObject<'py> for DatabaseMetrics
impl<'py> IntoPyObject<'py> for DatabaseMetrics
Sourcetype Target = DatabaseMetrics
type Target = DatabaseMetrics
The Python output type
Sourcetype Output = Bound<'py, <DatabaseMetrics as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DatabaseMetrics as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for DatabaseMetrics
impl PyClass for DatabaseMetrics
Sourceimpl PyClassImpl for DatabaseMetrics
impl PyClassImpl for DatabaseMetrics
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DatabaseMetrics>
type ThreadChecker = SendablePyClass<DatabaseMetrics>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyTypeInfo for DatabaseMetrics
impl PyTypeInfo for DatabaseMetrics
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for DatabaseMetrics
impl ExtractPyClassWithClone for DatabaseMetrics